@@ -18,7 +18,7 @@
 # Keep this in sync with sister test 'canon4.sh'.
 
 required='libtoolize'
-. ./defs || exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
