@@ -16,7 +16,7 @@
 
 # Check basic use of conditionals.
 
-. ./defs || Exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AM_CONDITIONAL([TEST], [true])
