@@ -19,7 +19,7 @@
 # broken in that case.
 
 required=GNUmake
-. ./defs || exit 1
+. test-init.sh
 
 cat > configure.ac << END
 AC_INIT([$me], [1.0])
