@@ -19,7 +19,7 @@
 # is empty.
 
 required=cscope
-. ./defs || exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_CONFIG_FILES([sub/Makefile])
