@@ -17,9 +17,9 @@
 # Test that AC_FC_SRCEXT(f9x) works as intended:
 # - $(FCFLAGS_f) will be used
 
-# Cf. fort1.test and link_f90_only.test.
+# Cf. 'fort1.sh' and 'link_f90_only.sh'.
 
-. ./defs || exit 1
+. test-init.sh
 
 mkdir sub
 
