@@ -17,7 +17,7 @@
 # Make sure --help and --version work, even when no configure.ac nor
 # configure.in is in the current directory.
 
-. ./defs || Exit 1
+. test-init.sh
 
 # Ensure we run in an empty directory.
 mkdir emptydir
@@ -35,12 +35,10 @@ $AUTOMAKE --help
 
 # Sanity checks: aclocal and automake cannot work without configure.ac
 # nor configure.in.
-$ACLOCAL 2>stderr && { cat stderr >&2; Exit 1; }
+$ACLOCAL 2>stderr && { cat stderr >&2; exit 1; }
 cat stderr >&2
 $FGREP configure.ac stderr
-$FGREP configure.in stderr
 AUTOMAKE_fails
 $FGREP configure.ac stderr
-$FGREP configure.in stderr
 
 :
