@@ -20,7 +20,7 @@
 # This is the java sister test of 'instfail.sh'.
 
 required=javac
-. ./defs || exit 1
+. test-init.sh
 
 cat >>configure.ac <<'END'
 AC_OUTPUT
