@@ -16,7 +16,7 @@
 
 # Test to make sure no-dist option works.
 
-. ./defs || exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
