@@ -22,7 +22,7 @@
 # sister test 'parallel-tests-fd-redirect.sh'.
 
 required='cc native'
-. ./defs || exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
