@@ -16,18 +16,8 @@
 
 # Colorized output from the testsuite report shouldn't end up in log files.
 
-. ./defs || Exit 1
-
-esc=''
-
-# Check that grep can parse nonprinting characters.
-# BSD 'grep' works from a pipe, but not a seekable file.
-# GNU or BSD 'grep -a' works on files, but is not portable.
-case `echo "$esc" | $FGREP "$esc"` in
-  "$esc") ;;
-# Creative quoting below to please maintainer-check.
-  *) echo "$me: f""grep can't parse nonprinting characters" >&2; Exit 77;;
-esac
+required='grep-nonprint'
+. test-init.sh
 
 TERM=ansi; export TERM
 
@@ -37,18 +27,17 @@ END
 
 cat >Makefile.am <<'END'
 LOG_COMPILER = $(SHELL)
-AUTOMAKE_OPTIONS = color-tests parallel-tests
+AUTOMAKE_OPTIONS = color-tests
 TESTS = pass fail skip xpass xfail error
 XFAIL_TESTS = xpass xfail
 END
 
-# Creative quoting to please maintainer-check.
-echo exit '0' > pass
-echo exit '0' > xpass
-echo exit '1' > fail
-echo exit '1' > xfail
-echo exit '77' > skip
-echo exit '99' > error
+echo 'exit 0' > pass
+echo 'exit 0' > xpass
+echo 'exit 1' > fail
+echo 'exit 1' > xfail
+echo 'exit 77' > skip
+echo 'exit 99' > error
 
 $ACLOCAL
 $AUTOCONF
@@ -56,7 +45,9 @@ $AUTOMAKE --add-missing
 
 ./configure
 mv config.log config-log # Avoid possible false positives below.
-AM_COLOR_TESTS=always $MAKE -e check && Exit 1
-$FGREP "$esc" *.log && Exit 1
+AM_COLOR_TESTS=always $MAKE -e check && exit 1
+# Not a useless use of cat; see above comments "grep-nonprinting"
+# requirement in 'test-init.sh'.
+cat *.log | grep "$esc" && exit 1
 
 :
