@@ -17,7 +17,7 @@
 # Test for += and backslashes.
 # Reported by Ralf Corsepius.
 
-. ./defs || Exit 1
+. test-init.sh
 
 cat >>configure.ac << 'END'
 AM_CONDITIONAL([A], [true])
@@ -48,7 +48,7 @@ $AUTOCONF
 $AUTOMAKE
 
 ./configure
-$MAKE print >stdout || { cat stdout; Exit 1; }
+$MAKE print >stdout || { cat stdout; exit 1; }
 cat stdout
 $FGREP 'BEG: 0.h a0.h a1.h a2.h a3.h :END' stdout
 
