@@ -27,7 +27,7 @@
 # the colon in the CONFIG_FILES variable.
 
 required=cc
-. ./defs || exit 1
+. test-init.sh
 
 cat > configure.ac << END
 AC_INIT([$me], [1.0])
