@@ -18,7 +18,7 @@
 # Dependency tracking -vs- nonstandard Makefile names
 
 required=cc
-. ./defs || Exit 1
+. test-init.sh
 
 cat > configure.ac << END
 AC_INIT([$me], [1.0])
