@@ -18,7 +18,7 @@
 #  - ':test-results:' directives in test scripts' output doesn't
 #    originate spurious results in the testsuite summary
 
-. ./defs || exit 1
+. test-init.sh
 
 . tap-setup.sh
 
