@@ -19,7 +19,7 @@
 # with NetBSD make).
 
 required='cc yacc'
-. ./defs || exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
